@@ -7,6 +7,7 @@ LastEditTime: 2022.02.02 18:14
 import click
 from click_aliases import ClickAliasedGroup
 
+from .java import java as _java
 from .python import python as _python
 from .raspberrypi import Version as raspberrypi_version, raspberrypi as _raspberrypi
 from .ubuntu import Version as ubuntu_version, ubuntu as _ubuntu, ubuntu_port
@@ -20,7 +21,7 @@ def command_cfm():
 @command_cfm.command(
     aliases=["py"],
     context_settings={"help_option_names": ["-h", "--help"]},
-    help="Change pypi & conda source minors.",
+    help="Change pypi & conda source mirrors.",
 )
 def python():
     _python()
@@ -29,7 +30,7 @@ def python():
 @command_cfm.command(
     aliases=["ub"],
     context_settings={"help_option_names": ["-h", "--help"]},
-    help="Change ubuntu/ubuntu-port source minors.",
+    help="Change ubuntu/ubuntu-port source mirrors.",
 )
 @click.option("--port/--no-port", "-p/", default=False)
 @click.option("--version", "-v", default=ubuntu_version.LTS2004)
@@ -43,8 +44,16 @@ def ubuntu(port, version):
 @command_cfm.command(
     aliases=["pi"],
     context_settings={"help_option_names": ["-h", "--help"]},
-    help="Change Raspberry Pi OS source minors.",
+    help="Change Raspberry Pi OS source mirrors.",
 )
 @click.option("--version", "-v", default=raspberrypi_version.Debian10)
 def raspberrypi(version):
     _raspberrypi(version)
+
+
+@command_cfm.command(
+    context_settings={"help_option_names": ["-h", "--help"]},
+    help="Change java source mirrors.",
+)
+def java():
+    _java()
