@@ -14,22 +14,22 @@ func init() {
 }
 
 func WebsocketServer(router *gin.RouterGroup) {
-	hub := newHub("example")
-	hub.broadcast = service.RealTimeMessageBroadcast
-	go hub.run()
+	hub := service.NewHub("message")
+	service.HubRealTimeMessageSubscriber = hubRealTimeMessageSubscriber
+	go hub.Run()
 
 	router.GET("/ws", func(c *gin.Context) {
-		conn, err := crossSiteUpgrader.Upgrade(c.Writer, c.Request, nil)
+		conn, err := service.CrossSiteUpgrader.Upgrade(c.Writer, c.Request, nil)
 		if err != nil {
 			log.Error().Msgf("ws: %v", err)
 			return
 		}
 
 		client := NewClient(hub, conn, nil, nil)
-		client.hub.register <- client
+		client.Hub.Register <- client
 
 		// Allow collection of memory referenced by the caller by doing all work in new goroutines.
-		go client.writePump()
-		go client.readPump()
+		go client.WritePump()
+		go client.ReadPump()
 	})
 }
