@@ -1,6 +1,7 @@
 {{SLASH_COMMENTS}}
 
 #include "core.h"
+#include "http_client/auth.h"
 #include <QEventLoop>
 #include <QFile>
 #include <QJsonDocument>
@@ -186,7 +187,7 @@ QList<QString> Core::getDistrictsByProvinceCity(const QString &province, const Q
 }
 
 // 常用加密函数封装
-std::string Core::AESEncryptStr(const QString &msgStr, const QString &keyStr) {
+QString Core::AESEncryptStr(const QString &msgStr, const QString &keyStr) {
     std::string msgStrOut;
 
     //    std::string msgStdStr = msgStr.toStdString();
@@ -199,10 +200,10 @@ std::string Core::AESEncryptStr(const QString &msgStr, const QString &keyStr) {
     //    ecbEncryptor.Put((byte *) plainText, strlen(plainText));
     //    ecbEncryptor.MessageEnd();
 
-    return msgStrOut;
+    return QString::fromStdString(msgStrOut);
 }
 
-std::string Core::AESDecryptStr(const QString &msgStr, const QString &keyStr) {
+QString Core::AESDecryptStr(const QString &msgStr, const QString &keyStr) {
     std::string msgStrOut;
 
     std::string msgStrBase64 = msgStr.toStdString();
@@ -220,7 +221,7 @@ std::string Core::AESDecryptStr(const QString &msgStr, const QString &keyStr) {
     //    stf.Put(reinterpret_cast<const unsigned char *>(msgStrEnc.c_str()), msgStrEnc.length());
     //    stf.MessageEnd();
 
-    return msgStrOut;
+    return QString::fromStdString(msgStrOut);
 }
 
 void Core::connectToWebsocketServer(const QString &s) {
@@ -230,7 +231,25 @@ void Core::connectToWebsocketServer(const QString &s) {
 
     qInfo().noquote() << QString("ws: connecting to %1").arg(websocketUrl);
 
-    websocketClient->open(websocketUrl);
+    Digest digest = {
+            "48619c2a",
+            "7fb58b0205e",
+            "GET",
+            QUrl(websocketUrl).path().toLocal8Bit(),
+            "gin@golang",
+    };
+
+    QString authValue = generateDigestAuthentication(digest);
+
+    QNetworkRequest request;
+    request.setUrl(websocketUrl);
+    request.setRawHeader("Authorization", authValue.toUtf8());
+
+    qDebug().noquote() << authValue;
+
+    websocketClient->open(request);
+
+    // websocketClient->open(websocketUrl);
 }
 
 void Core::onWebsocketConnected() {
@@ -255,7 +274,7 @@ void Core::onWebsocketDisconnected() {
     }
 }
 
-void Core::sendTextMessageToWebsocketServer(const QString &textMessage) {
+void Core::onSendTextMessageToWebsocketServer(const QString &textMessage) {
     qInfo().noquote() << QString("ws: sent '%1'").arg(textMessage.simplified());
 
     websocketClient->sendTextMessage(textMessage);
@@ -293,10 +312,10 @@ void Core::websocketKeepAlive() {
     emit sendTextMessageToWebsocketServer(QJsonDocument(obj).toJson());
 }
 
-QJsonObject Core::httpRequest(const QByteArray &method, const QString &url, const QByteArray &body = "", bool customUrl = false) {
-    auto *httpClient = new QNetworkAccessManager();
+QJsonObject Core::httpRequest(const QByteArray &method, const QString &url, const QByteArray &body = "", bool customUrl = false, const QByteArray &authValue = "") {
+    auto httpClient = new QNetworkAccessManager();
 
-   auto httpUrl = customUrl ? url : remoteHttpBaseUrl + url;
+    auto httpUrl = customUrl ? url : remoteHttpBaseUrl + url;
     if (!httpUrl.startsWith("http")) {
         httpUrl = "http://" + httpUrl;
     }
@@ -304,6 +323,10 @@ QJsonObject Core::httpRequest(const QByteArray &method, const QString &url, cons
     QNetworkRequest request;
     request.setUrl(httpUrl);
 
+    if (!authValue.isEmpty()) {
+        request.setRawHeader("Authorization", authValue);
+    }
+
     qInfo().noquote() << QString("core: %1 %2").arg(method, url);
 
     if (!body.isEmpty()) {
@@ -345,12 +368,12 @@ QJsonObject Core::httpRequest(const QByteArray &method, const QString &url, cons
     return responseJson;
 }
 
-QJsonObject Core::httpGet(const QString &url, bool customUrl = false) {
-    return httpRequest("GET", url, "", customUrl);
+QJsonObject Core::httpGet(const QString &url, bool customUrl = false, const QByteArray &authValue = "") {
+    return httpRequest("GET", url, "", customUrl, authValue);
 }
 
-QJsonObject Core::httpPost(const QString &url, const QByteArray &body, bool customUrl = false) {
-    return httpRequest("POST", url, body, customUrl);
+QJsonObject Core::httpPost(const QString &url, const QByteArray &body, bool customUrl = false, const QByteArray &authValue = "") {
+    return httpRequest("POST", url, body, customUrl, authValue);
 }
 
 QByteArray Core::parseDate(QByteArray d) {
@@ -378,23 +401,36 @@ void Core::DoSomethingForeverConcurrent() {
 void Core::onRun() {
     qInfo() << "Running...";
 
-    httpGet("http://httpbin.org/get", true);
+    QByteArray httpUrl = "http://localhost:8787/debug";
 
-    httpPost("http://httpbin.org/post",
-             QJsonDocument(
-                     QJsonObject{
-                             {"q", "typescript"},
-                             {"image", "base64"},
-                             {"debug", debugMode},
-                             {"json", "This is a json object."}})
-                     .toJson(),
-             true);
+    Digest digest = {
+            "admin",
+            "admin",
+            "GET",
+            QUrl(httpUrl).path().toLocal8Bit(),
+            "gin@golang",
+    };
 
-    //    DoSomethingForever();
+    QString authValue = generateDigestAuthentication(digest);
+
+    httpGet(httpUrl, true, authValue.toUtf8());
+    connectToWebsocketServer("typescript");
+
+    //    httpPost("http://localhost:12780/post",
+    //             QJsonDocument(
+    //                     QJsonObject{
+    //                             {"q", "typescript"},
+    //                             {"image", "base64"},
+    //                             {"debug", debugMode},
+    //                             {"json", "This is a json object."}})
+    //                     .toJson(),
+    //             true);
+
+//        DoSomethingForever();
     //    DoSomethingForeverConcurrent();
 
     // do something
-    emit finished();
+//    emit finished();
 
     qInfo() << "I thought I'd finished!";
 }
